//
//  ViewController.m
//  CellCarousel
//
//  Created by Stephen Zaharuk on 3/16/16.
//  Copyright © 2016 Stephen Zaharuk. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()<IGGridViewDataSource, IGGridViewDelegate>
{
    IGGridView* gridView;
}
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];

    
    gridView = [[IGGridView alloc]init];
    [self.view addSubview:gridView];
    

    
    gridView.clipsToBounds = NO;
    gridView.headerHeight = 0;
    gridView.selectionType = IGGridViewSelectionTypeNone;
    gridView.rowSeparatorHeight = 0;
    gridView.emptyRows = NO;
    gridView.alwaysBounceVertical = NO;
    gridView.allowHorizontalBounce = YES;

    
    gridView.delegate = self;
    
    [gridView setShowsHorizontalScrollIndicator:NO];
    [gridView setShowsVerticalScrollIndicator:NO];
    [gridView registerClass:[CarouselViewCell class] forCellReuseIdentifier:@"cell"];
    
    
    gridView.dataSource = self;
    
    CGFloat thickness = 1;
    UIView* line = [[UIView alloc]initWithFrame:CGRectMake(self.view.bounds.size.width/2 - thickness/2, 0, thickness, self.view.bounds.size.height)];
    line.backgroundColor = [UIColor greenColor];
    line.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleRightMargin;
    [self.view addSubview:line];

}

-(void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    
    //CGFloat rowHeight = .30;
    //CGFloat base = MIN(self.view.frame.size.width, self.view.frame.size.height);
    CGFloat height = self.view.bounds.size.width/5;
    
    gridView.frame = CGRectMake(0, self.view.bounds.size.height/2 - height/2, self.view.frame.size.width, height);
    
    gridView.rowHeight = height;
    gridView.columnWidth = [IGColumnWidth CreateWithFixedWidth:gridView.rowHeight];
    
    CGFloat cellSpacing = 0;//(self.view.frame.size.width / 11); // this value brings the cells together and displays 5 cell on
    gridView.columnSpacing = -cellSpacing;
    
    CGFloat cellSize = gridView.rowHeight - cellSpacing;
    CGFloat inset = self.view.bounds.size.width/2 - cellSize/2 + cellSpacing/2;
    gridView.contentInset = UIEdgeInsetsMake(0, inset, 0, inset);
    
    [gridView updateData ];
}

-(NSInteger)numberOfColumnsInGridView:(IGGridView *)gridView
{
    return 10;
}

-(NSInteger)numberOfSectionsInGridView:(IGGridView *)gridView
{
    return 1;
}

-(NSInteger)gridView:(IGGridView *)gridView numberOfRowsInSection:(NSInteger)section
{
    return 1;
}

-(IGGridViewCell *)gridView:(IGGridView *)gv cellAt:(IGCellPath *)path
{
    CarouselViewCell* cell = [gridView dequeueReusableCellWithIdentifier:@"cell"];
    
    return cell;
}


@end

@interface CarouselViewCell()
{
    UIView* _circleView;
}

@end

@implementation CarouselViewCell

-(instancetype)init
{
    self = [super init];
    if(self)
    {
        _circleView = [[UIView alloc]init];
        _circleView.backgroundColor = [UIColor colorWithRed:29/225.0f green:173/225.0f blue:233/225.0f alpha:1];
        _circleView.layer.borderWidth = 1;
        _circleView.layer.borderColor = [UIColor blackColor].CGColor;
        [self addSubview:_circleView];
    }
    return self;
}
-(CGFloat)min{
    return .4f;
}

-(CGFloat)max{
    return 1.5f;
}



-(void)cellLocationInViewportChanged:(CGPoint)location
{
    CGFloat width = self.bounds.size.width;
    CGFloat height = self.bounds.size.height;
    CGFloat itemSize = width;
    
    
    CALayer* layer = [_circleView layer];
    [layer setMasksToBounds:YES];
    
    CGFloat originalScale = [self centerLocation:location.x];
    CGFloat scale = ((self.max - self.min) * originalScale) + self.min;
    
    BOOL isLeft = location.x < .5f;

    
    
    CGFloat scaledItemSize = scale * itemSize;
    
    CGFloat x = width/2 - scaledItemSize/2;
    CGFloat additionalOffset =  0;

    CGFloat maxScale = self.max;
    CGFloat minScale = maxScale - .2f;
    CGFloat spacing = scaledItemSize/2;
    if(scale < minScale)
    {
        additionalOffset = spacing;
    }
    else
    {
        
        CGFloat multiplier = ((maxScale - scale)/ (maxScale - minScale));
        additionalOffset = spacing * multiplier;
    }
    
     NSLog(@"%@ - %f - %f - %f", self.path.description, location.x,  scale, additionalOffset);
    
    if(isLeft)
        additionalOffset *= -1;
    
    x += additionalOffset;

    _circleView.frame = CGRectMake(x, height/2 - scaledItemSize/2, scaledItemSize, scaledItemSize);
    _circleView.layer.cornerRadius = scaledItemSize/2;

    self.layer.zPosition = scale;

}

- (void)applyScale:(CGFloat)percent toView:(UIView*)view
{
    CATransform3D transform = view.layer.transform;
    transform = CATransform3DScale(transform, percent, percent, percent);
    view.layer.transform = transform;
}

-(CGFloat)centerLocation:(CGFloat)val{
    if (val >= .5){
        val = 1 - val;
    }
    
    if (val <= .5){
        val = val / .5;
    }
    
    return val;
}

@end
